@@ -2,11 +2,12 @@ from digitalguide.whatsapp.WhatsAppUpdate import WhatsAppUpdate
 
 
 def whatsapp_default_name(client, update: WhatsAppUpdate, context):
-    context["name"] = update.ProfileName
+    context["name"] = update.entry[0].changes[0].value.contacts[0].profile_name
 
 
 def whatsapp_save_text_to_context(client, update: WhatsAppUpdate, context, key):
-    context[key] = update.Body
+    if update.get_message()._type == "text":
+        context[key] = update.get_message().text
 
 
 def whatsapp_save_value_to_context(client, update: WhatsAppUpdate, context, key, value):
